@@ -4,8 +4,6 @@ Utilities for extracting types from annotations.
 :author: Doug Skrypa
 """
 
-from __future__ import annotations
-
 from collections.abc import Collection, Iterable
 from inspect import isclass
 from typing import Union, Optional, get_type_hints, get_origin, get_args as _get_args  # pylint: disable=C0412
@@ -27,18 +25,14 @@ def get_descriptor_value_type(command_cls: type, attr: str) -> Optional[type]:
     return get_annotation_value_type(annotation)
 
 
-def get_annotation_value_type(annotation) -> Optional[type]:
+def get_annotation_value_type(annotation, from_union: bool = True, from_collection: bool = True) -> Optional[type]:
     origin = get_origin(annotation)
-    # Note on get_origin return values:
-    # get_origin(List[str]) -> list
-    # get_origin(List) -> list
-    # get_origin(list[str]) -> list
-    # get_origin(list) -> None
+    # Note: get_origin returns `list` for `List[str]`, `List`, and `list[str]`; it returns `None` for `list`
     if origin is None and isinstance(annotation, type):
         return annotation
-    elif isclass(origin) and issubclass(origin, (Collection, Iterable)):
+    elif from_collection and isclass(origin) and issubclass(origin, (Collection, Iterable)):
         return _type_from_collection(origin, annotation)
-    elif origin is Union:
+    elif from_union and origin is Union:
         return _type_from_union(annotation)
     return None
 
@@ -56,34 +50,14 @@ def _type_from_union(annotation) -> Optional[type]:
     args = get_args(annotation)
     # Note: Unions of a single argument return the argument; i.e., Union[T] returns T, so the len can never be 1
     if len(args) == 2 and NoneType in args:
-        arg = args[0] if args[1] is NoneType else args[1]
-    else:
-        return None
-
-    origin = get_origin(arg)
-    if origin is None and isinstance(arg, type):
-        return arg
-    elif isclass(origin) and issubclass(origin, (Collection, Iterable)):
-        return _type_from_collection(origin, arg)
-    else:
-        return None
+        return get_annotation_value_type(args[0] if args[1] is NoneType else args[1], from_union=False)
+    return None
 
 
 def _type_from_collection(origin, annotation) -> Optional[type]:
-    args = get_args(annotation)
-    try:
-        annotation = args[0]
-    except IndexError:  # The annotation was a collection with no content types specified
-        return origin
-
+    if not (args := get_args(annotation)):
+        return origin  # The annotation was a collection with no content types specified
     n_args = len(args)
-    if n_args > 1 and (origin is not tuple or not ((n_args == 2 and args[1] is Ellipsis) or len(set(args)) == 1)):
-        return None
-
-    origin = get_origin(annotation)
-    if origin is None and isinstance(annotation, type):
-        return annotation
-    elif origin is Union:
-        return _type_from_union(annotation)
-    else:
-        return None
+    if n_args == 1 or (origin is tuple and ((n_args == 2 and args[1] is Ellipsis) or len(set(args)) == 1)):
+        return get_annotation_value_type(args[0], from_collection=False)
+    return None
